@@ -1,7 +1,7 @@
-`repolr` <-
+repolr <-
 function(formula,subjects,data,times,categories,
-           scalevalue=1,corstr="ar1",maxiter=10,tol=0.001,
-           alpha=0.5,po.test=TRUE,fixed=FALSE){
+           scalevalue=1,corstr="independence",maxiter=10,tol=0.001,
+           alpha=0.5,po.test=FALSE,fixed=FALSE){
 
  # load functions
  
@@ -513,8 +513,7 @@ function(formula,subjects,data,times,categories,
  }
 
  # introductory message 
- cat(" REPOLR: 28/02/2008 version 1.1","\n")
- cat(" using gee 4.13 GEE C source version chanlib 4.12","\n")
+
  call <- match.call()
 
  # check correlation structure, maxiter, scalevalue, alpha, categories
@@ -570,8 +569,8 @@ function(formula,subjects,data,times,categories,
  miss_data <- as.data.frame(cbind(sub_ind,miss_ind))
 
  # fit gee model to get initial parameter estimates
- mod.gee <- ogee(formula,data=exdata$exdata,id=exdata$exdata$subjects,family="binomial",
-     scale.fix=TRUE,scale.value=scalevalue,corstr="independence",maxiter=20,silent=TRUE)
+ mod.gee <- suppressWarnings(gee(formula,data=exdata$exdata,id=exdata$exdata$subjects,family="binomial",
+     scale.fix=TRUE,scale.value=scalevalue,corstr="independence",maxiter=20,silent=TRUE))
  coeffs <- mod.gee$coeff
 
  # fit gee model
@@ -618,9 +617,9 @@ function(formula,subjects,data,times,categories,
   }
 
   # fit GEE
-  mod.gee <- ogee(formula,data=exdata$exdata,id=exdata$exdata$subjects,
+  mod.gee <- suppressWarnings(gee(formula,data=exdata$exdata,id=exdata$exdata$subjects,
      family="binomial",b=as.numeric(coeffs),scale.fix=TRUE,scale.value=scalevalue,
-     corstr="fixed",maxiter=10,R=R_mat,silent=TRUE)
+     corstr="fixed",maxiter=10,R=R_mat,silent=TRUE))
 
   # stopping criterion
   crit <- abs(1-sqrt(sum((coeffs/mod.gee$coeff)^2)/length(coeffs)))
@@ -628,45 +627,55 @@ function(formula,subjects,data,times,categories,
 
   # monitor
   iterct <- iterct+1
-  if (iterct==1){
-    cat(format("iter",digits=1,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
-        "\t",format("crit",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-        "\t",format("alpha",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-        "\t",format("grad1",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-        "\t",format("grad2",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
+  if (iterct==1){monitor.crit <- crit} else {monitor.crit <- append(monitor.crit,crit)}
+  if(corstr!="independence"){
+   if (iterct==1){monitor.alpha <- alpha} else {monitor.alpha <- append(monitor.alpha,alpha)}
   }
-
-  if (corstr=="independence"){
-     cat(format(round(iterct,0),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
-     "\t",format(round(crit,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
-  } else {
-    if (fixed==FALSE){
-    cat(format(round(iterct,0),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
-     "\t",format(round(crit,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format(round(alpha,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format(round(pupdate$gVB,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format(round(pupdate$ggVB,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
-    }
-    if (fixed==TRUE){
-     cat(format(round(iterct,0),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
-     "\t",format(round(crit,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format(round(alpha,5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
-     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
-    }
-  }
-  if (iterct<=4){
-   ogstop <- 1
-  }else{
-   ogstop <- crit
+  if(fixed==FALSE & corstr!="independence"){
+   if (iterct==1){monitor.grad1 <- pupdate$gVB} else {monitor.grad1 <- append(monitor.grad1,pupdate$gVB)}
+   if (iterct==1){monitor.grad2 <- pupdate$ggVB} else {monitor.grad2 <- append(monitor.grad2,pupdate$ggVB)}
   }
+  if (iterct<=4){ogstop <- 1} else {ogstop <- crit}
 
   } # end of while
 
 
+  # print monitor
+  cat("\n")
+  cat(" REPOLR: 2013-03-20 version 2.0","\n")
+  cat(" Working correlation model: ",corstr,"\n")
+  cat(" Convergence monitor","\n")
+  cat("\n")
+  cat(format("iter",digits=1,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
+        "\t",format("crit",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+        "\t",format("alpha",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+        "\t",format("grad1",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+        "\t",format("grad2",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n") 
+  for (cmont in 1:iterct){
+   if (corstr=="independence"){
+     cat(format(round(cmont,0),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
+     "\t",format(round(monitor.crit[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
+   } else {
+    if (fixed==FALSE){
+    cat(format(round(cmont,0),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
+     "\t",format(round(monitor.crit[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format(round(monitor.alpha[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format(round(monitor.grad1[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format(round(monitor.grad2[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
+    }
+    if (fixed==TRUE){
+     cat(format(round(iterct,0),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=0,width=8),
+     "\t",format(round(monitor.crit[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format(round(monitor.alpha[cmont],5),digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),
+     "\t",format("-",digits=5,trim=TRUE,justify="right",scientific=FALSE,nsmall=5,width=8),"\n")
+    }
+   }
+  }
+
   # score test
   if (po.test==TRUE){
    exformula <- as.formula(paste(resp_label,"~",
@@ -692,8 +701,7 @@ function(formula,subjects,data,times,categories,
    alpha_u <- exp(phi_u)/(1+exp(phi_u))
    alpha_l <- exp(phi_l)/(1+exp(phi_l))
    if (po.test!=TRUE){cat("\n")}
-   cat(" Correlation parameter (95% CI):",round(alpha,3)," (",round(alpha_l,3),
-                     ", ",round(alpha_u,3),")","\n")
+   cat(" Correlation parameter:",round(alpha,3),"\n")
   } else {
    warning(" grad2 < 0: minimum for alpha not achieved")
   }
@@ -701,20 +709,29 @@ function(formula,subjects,data,times,categories,
 
  # fitted model
  mod.corr <- list()
+ mod.corr$x <- X_mat
  mod.corr$subjects <- subjects
  mod.corr$categories <- categories
  mod.corr$times <- times
  mod.corr$corstr <- corstr
  mod.corr$crit <- crit
- mod.corr$score.test <- test_stat
+ if(po.test==TRUE){
+  mod.corr$score.test <- test_stat
+ } else {
+  mod.corr$score.test <- NULL
+ }
  mod.corr$iter <- iterct
  mod.corr$scale <- scalevalue
  mod.corr$data <- call[["data"]]
  if (corstr!="independence"){
   mod.corr$alpha <- alpha
+  if (fixed==FALSE){
   mod.corr$grad1 <- pupdate$gVB
   mod.corr$grad2 <- pupdate$ggVB
+  } else {
+  mod.corr$grad1 <- NULL
+  mod.corr$grad2 <- NULL
+  }
  }
  list(gee=mod.gee,corr=mod.corr)
 }
-
